/* $Id: ethtool.h,v 1.2 2001/01/31 05:38:16 davem Exp $
 * ethtool.h: Defines for SparcLinux ethtool.
 *
 * Copyright (C) 1998 David S. Miller (davem@dm.cobaltmicro.com)
 */

#ifndef _ETHTOOL_H
#define _ETHTOOL_H

/* We do things like this so it does not matter what kernel
 * headers you have on your system etc.
 */
#undef SIOCETHTOOL
#define SIOCETHTOOL	0x8946

/* This should work for both 32 and 64 bit userland. */
struct ethtool_cmd {
	u_int32_t	cmd;
	u_int32_t	supported;	/* Features this interface supports */
	u_int32_t	advertising;	/* Features this interface advertises */
	u_int16_t	speed;		/* The forced speed, 10Mb, 100Mb, gigabit */
	u_int8_t	duplex;		/* Duplex, half or full */
	u_int8_t	port;		/* Which connector port */
	u_int8_t	phy_address;
	u_int8_t	transceiver;	/* Which tranceiver to use */
	u_int8_t	autoneg;	/* Enable or disable autonegotiation */
	u_int32_t	maxtxpkt;	/* Tx pkts before generating tx int */
	u_int32_t	maxrxpkt;	/* Rx pkts before generating rx int */
	u_int32_t	reserved[4];
};


/* CMDs currently supported */
#define ETHTOOL_GSET		0x00000001 /* Get settings, non-privileged. */
#define ETHTOOL_SSET		0x00000002 /* Set settings, privileged. */

/* compatibility with older code */
#define SPARC_ETH_GSET		ETHTOOL_GSET
#define SPARC_ETH_SSET		ETHTOOL_SSET

/* Indicates what features are supported by the interface. */
#define SUPPORTED_10baseT_Half		(1 << 0)
#define SUPPORTED_10baseT_Full		(1 << 1)
#define SUPPORTED_100baseT_Half		(1 << 2)
#define SUPPORTED_100baseT_Full		(1 << 3)
#define SUPPORTED_1000baseT_Half	(1 << 4)
#define SUPPORTED_1000baseT_Full	(1 << 5)
#define SUPPORTED_Autoneg		(1 << 6)
#define SUPPORTED_TP			(1 << 7)
#define SUPPORTED_AUI			(1 << 8)
#define SUPPORTED_MII			(1 << 9)
#define SUPPORTED_FIBRE			(1 << 10)

/* Indicates what features are advertised by the interface. */
#define ADVERTISED_10baseT_Half		(1 << 0)
#define ADVERTISED_10baseT_Full		(1 << 1)
#define ADVERTISED_100baseT_Half	(1 << 2)
#define ADVERTISED_100baseT_Full	(1 << 3)
#define ADVERTISED_1000baseT_Half	(1 << 4)
#define ADVERTISED_1000baseT_Full	(1 << 5)
#define ADVERTISED_Autoneg		(1 << 6)
#define ADVERTISED_TP			(1 << 7)
#define ADVERTISED_AUI			(1 << 8)
#define ADVERTISED_MII			(1 << 9)
#define ADVERTISED_FIBRE		(1 << 10)

/* The following are all involved in forcing a particular link
 * mode for the device for setting things.  When getting the
 * devices settings, these indicate the current mode and whether
 * it was foced up into this mode or autonegotiated.
 */

/* The forced speed, 10Mb, 100Mb, gigabit. */
#define SPEED_10		10
#define SPEED_100		100
#define SPEED_1000		1000

/* Duplex, half or full. */
#define DUPLEX_HALF		0x00
#define DUPLEX_FULL		0x01

/* Which connector port. */
#define PORT_TP			0x00
#define PORT_AUI		0x01
#define PORT_MII		0x02
#define PORT_FIBRE		0x03
#define PORT_BNC		0x04

/* Which tranceiver to use. */
#define XCVR_INTERNAL		0x00
#define XCVR_EXTERNAL		0x01
#define XCVR_DUMMY1		0x02
#define XCVR_DUMMY2		0x03
#define XCVR_DUMMY3		0x04

/* Enable or disable autonegotiation.  If this is set to enable,
 * the forced link modes above are completely ignored.
 */
#define AUTONEG_DISABLE		0x00
#define AUTONEG_ENABLE		0x01

#endif /* !(_ETHTOOL_H) */
